@@ -6,7 +6,7 @@ module RapidDiffs
     include ActionController::Live
     include DiffHelper
 
-    def diffs
+    def diffs_stream
       streaming_start_time = Process.clock_gettime(Process::CLOCK_MONOTONIC)
 
       stream_headers
@@ -40,10 +40,6 @@ module RapidDiffs
 
     private
 
-    def resource
-      raise NotImplementedError
-    end
-
     def streaming_diff_options
       diff_options
     end
@@ -53,7 +49,7 @@ module RapidDiffs
     end
 
     def stream_diff_files(options, view_context)
-      return unless resource
+      return unless rapid_diffs_presenter
 
       # NOTE: This is a temporary flag to test out the new diff_blobs
       use_new_gitaly_rpc = ActiveModel::Type::Boolean.new.cast(params.permit(:diff_blobs)[:diff_blobs])
@@ -65,12 +61,17 @@ module RapidDiffs
     end
 
     def stream_diff_collection(options, view_context)
-      diff_files = resource.diffs_for_streaming(options).diff_files(sorted: sorted?)
+      diff_files = rapid_diffs_presenter.diff_files_for_streaming(options)
 
       return render_empty_state if diff_files.empty?
 
+      old_path = params.permit(:skip_old_path)[:skip_old_path]
+      new_path = params.permit(:skip_new_path)[:skip_new_path]
+
       skipped = []
       diff_files.each do |diff_file|
+        next if old_path && new_path && diff_file.old_path == old_path && diff_file.new_path == new_path
+
         if diff_file.no_preview?
           skipped << diff_file
         else
@@ -103,9 +104,9 @@ module RapidDiffs
     end
 
     def stream_diff_blobs(options, view_context)
-      return render_empty_state if resource.diffs_for_streaming(options).count == 0
+      return render_empty_state if rapid_diffs_presenter.diff_files_for_streaming(options).count == 0
 
-      resource.diffs_for_streaming(options) do |diff_files_batch|
+      rapid_diffs_presenter.diff_files_for_streaming_by_changed_paths(options) do |diff_files_batch|
         response.stream.write(diff_files_collection(diff_files_batch).render_in(view_context))
       end
     end
@@ -114,10 +115,6 @@ module RapidDiffs
       response.stream.write render ::RapidDiffs::EmptyStateComponent.new, layout: false
     end
 
-    def sorted?
-      false
-    end
-
     class Request < SimpleDelegator
       def format
         Mime::Type.lookup("text/html")
