@@ -4,32 +4,23 @@ module UserSettings
   class PersonalAccessTokensController < ApplicationController
     include FeedTokenHelper
 
+    GITLAB_WORKFLOW_EXTENSION = "GitLab Workflow Extension"
+
     feature_category :system_access
 
     before_action :check_personal_access_tokens_enabled
+    before_action :ensure_granular_tokens_feature_flag, only: [:legacy_new, :granular_new]
+    before_action :set_access_token_params, only: [:index, :legacy_new]
+
     prepend_before_action(only: [:index]) { authenticate_sessionless_user!(:ics) }
 
     def index
-      scopes = []
-      unless params[:scopes].nil?
-        # An over engineered solution to generate scopes array without extra object allocations
-        params[:scopes].split(",", Gitlab::Auth.all_available_scopes.count + 1) do |scope|
-          scope = scope.squish
-          next if scope.empty?
+      if redirect_for_vscode_extension?
+        redirect_to action: :legacy_new, **vscode_extension_params
 
-          scope = scope.to_sym
-          next if Gitlab::Auth.all_available_scopes.exclude?(scope)
-
-          scopes << scope
-        end
+        return
       end
 
-      @access_token_params = {
-        name: params[:name],
-        description: params[:description],
-        scopes: scopes
-      }
-
       respond_to do |format|
         format.html
         format.ics do
@@ -43,8 +34,12 @@ module UserSettings
       end
     end
 
+    def legacy_new
+      # Renders the legacy create form on a dedicated page
+    end
+
     def granular_new
-      render_404 unless Feature.enabled?(:granular_personal_access_tokens, current_user)
+      # Renders the granular create form on a dedicated page
     end
 
     def create
@@ -82,10 +77,22 @@ module UserSettings
 
     private
 
+    def set_access_token_params
+      @access_token_params = {
+        name: params[:name],
+        description: params[:description],
+        scopes: parse_scopes_from_params
+      }
+    end
+
     def expiry_ics
-      tokens =
-        PersonalAccessTokensFinder.new({ user: current_user, impersonation: false, state: 'active',
-                                         sort: 'expires_asc' }).execute.preload_users
+      tokens = PersonalAccessTokensFinder.new({
+        user: current_user,
+        impersonation: false,
+        state: 'active',
+        sort: 'expires_asc'
+      }).execute.preload_users
+
       cal = Icalendar::Calendar.new
       tokens.each do |token|
         next unless token.expires_at
@@ -96,6 +103,7 @@ module UserSettings
           event.summary = format(_("Token '%{name}' expires today"), name: token.name)
         end
       end
+
       cal.to_ical
     end
 
@@ -103,13 +111,44 @@ module UserSettings
       params.require(:personal_access_token).permit(:name, :expires_at, :description, scopes: [])
     end
 
+    def vscode_extension_params
+      params.permit(:name, :description, :scopes)
+    end
+
     def dpop_params
       params.require(:user).permit(:dpop_enabled)
     end
 
+    def parse_scopes_from_params
+      return [] if params[:scopes].nil?
+
+      scopes = []
+
+      params[:scopes].split(",", Gitlab::Auth.all_available_scopes.count + 1) do |scope|
+        scope = scope.squish
+        next if scope.empty?
+
+        scope = scope.to_sym
+        next if Gitlab::Auth.all_available_scopes.exclude?(scope)
+
+        scopes << scope
+      end
+
+      scopes
+    end
+
     def check_personal_access_tokens_enabled
       render_404 if Gitlab::CurrentSettings.personal_access_tokens_disabled?
     end
+
+    def ensure_granular_tokens_feature_flag
+      render_404 unless Feature.enabled?(:granular_personal_access_tokens, current_user)
+    end
+
+    def redirect_for_vscode_extension?
+      Feature.enabled?(:granular_personal_access_tokens, current_user) &&
+        params[:name]&.casecmp?(GITLAB_WORKFLOW_EXTENSION)
+    end
   end
 end
 
