@@ -75,6 +75,7 @@ module Ci
     def filter_builds(builds)
       builds = filter_by_with_artifacts(builds)
       builds = filter_by_runner_types(builds)
+      builds = filter_by_pipeline_iid(builds)
       filter_by_scope(builds)
     end
 
@@ -127,6 +128,12 @@ module Ci
         raise ArgumentError, "finder does not support #{type} type"
       end
     end
+
+    def filter_by_pipeline_iid(builds)
+      return builds.with_pipeline_iid(@project.id, params[:pipeline_iid]) if params[:pipeline_iid]
+
+      builds
+    end
   end
 end
 
