@@ -23,6 +23,7 @@ class NotesFinder
     @project = params[:project]
     @current_user = current_user
     @params = params.dup
+    @organization_id = @params.delete(:organization_id)
     @target_type = @params[:target_type]
   end
 
@@ -118,9 +119,9 @@ class NotesFinder
     when "merge_request"
       MergeRequestsFinder.new(@current_user, project_id: @project.id).execute # rubocop: disable CodeReuse/Finder
     when "snippet", "project_snippet"
-      SnippetsFinder.new(@current_user, project: @project).execute # rubocop: disable CodeReuse/Finder
+      SnippetsFinder.new(@current_user, organization_id: @organization_id, project: @project).execute # rubocop: disable CodeReuse/Finder
     when "personal_snippet"
-      SnippetsFinder.new(@current_user, only_personal: true).execute # rubocop: disable CodeReuse/Finder
+      SnippetsFinder.new(@current_user, organization_id: @organization_id, only_personal: true).execute # rubocop: disable CodeReuse/Finder
     when "wiki_page/meta"
       WikiPage::Meta.for_project(@project)
     else
