@@ -6,14 +6,14 @@ module Mutations
       graphql_name 'UpdateAlertStatus'
 
       argument :status, Types::AlertManagement::StatusEnum,
-               required: true,
-               description: 'Status to set the alert.'
+        required: true,
+        description: 'Status to set the alert.'
 
       def resolve(project_path:, iid:, status:)
         alert = authorized_find!(project_path: project_path, iid: iid)
         result = update_status(alert, status)
 
-        track_usage_event(:incident_management_alert_status_changed, current_user.id)
+        track_alert_events('incident_management_alert_status_changed', alert)
 
         prepare_response(result)
       end
