@@ -38,6 +38,25 @@ module Observability
       HUMANIZED_ATTRIBUTES[attribute.to_sym] || super
     end
 
+    def self.observability_setting_for(resource)
+      return unless resource
+
+      group = resource.is_a?(Project) ? resource.group : resource
+      return unless group.is_a?(Group)
+
+      ancestor_ids = group.traversal_ids.reverse
+      return if ancestor_ids.empty?
+
+      # Find the first setting matching any ancestor, maintaining hierarchy order
+      # by using array_position to preserve the order from ancestor_ids
+      group_id_attribute = arel_table[:group_id]
+      array_sql = "array_position(ARRAY[#{ancestor_ids.join(',')}]::bigint[], " \
+        "#{group_id_attribute.relation.name}.#{group_id_attribute.name})"
+      where(group_id: ancestor_ids)
+        .order(Arel.sql(array_sql))
+        .first
+    end
+
     def o11y_service_name
       @o11y_service_name || name_from_url || name_from_group
     end
@@ -63,18 +82,28 @@ module Observability
       errors.add(:o11y_service_user_email, I18n.t(:invalid, scope: 'valid_email.validations.email'))
     end
 
+    def provisioning?
+      within_provisioning_window? || new_record?
+    end
+
+    def otel_http_endpoint
+      "http://#{otel_address}:4318"
+    end
+
+    def otel_grpc_endpoint
+      "http://#{otel_address}:4317"
+    end
+
+    def otel_address
+      "#{o11y_service_name}.otel.gitlab-o11y.com"
+    end
+
+    private
+
     def within_provisioning_window?
       return false unless persisted?
 
       Time.current.before?(created_at + SETUP_WINDOW)
     end
-
-    def otel_http_endpoint
-      "http://#{o11y_service_name}.otel.gitlab-o11y.com:4318"
-    end
-
-    def otel_grpc_endpoint
-      "http://#{o11y_service_name}.otel.gitlab-o11y.com:4317"
-    end
   end
 end
