@@ -30,7 +30,16 @@ module Projects
           can_enable_spp: can_enable_spp?,
           is_gitlab_com: gitlab_com?,
           secret_detection_configuration_path: secret_detection_configuration_path,
-          license_configuration_source: license_configuration_source
+          license_configuration_source: license_configuration_source,
+          vulnerability_training_docs_path: vulnerability_training_docs_path,
+          upgrade_path: upgrade_path,
+          group_full_path: group_full_path,
+          can_apply_profiles: can_apply_profiles?,
+          can_read_attributes: can_read_attributes?,
+          can_manage_attributes: can_manage_attributes?,
+          security_scan_profiles_licensed: security_scan_profiles_licensed?,
+          group_manage_attributes_path: group_manage_attributes_path,
+          max_tracked_refs: max_tracked_refs
         }
       end
 
@@ -51,6 +60,10 @@ module Projects
         project.licensed_feature_available?(:secret_push_protection)
       end
 
+      def security_scan_profiles_licensed?
+        project.licensed_feature_available?(:security_scan_profiles)
+      end
+
       def can_enable_auto_devops?
         feature_available?(:builds, current_user) &&
           user_is_project_admin? &&
@@ -118,13 +131,52 @@ module Projects
         project.security_setting
       end
 
+      def vulnerability_training_docs_path
+        help_page_path(
+          'user/application_security/vulnerabilities/_index.md',
+          anchor: 'enable-security-training-for-vulnerabilities'
+        )
+      end
+
+      def upgrade_path
+        promo_pricing_url
+      end
+
+      def group_full_path
+        root_group.full_path if root_group
+      end
+
+      def can_apply_profiles?
+        return false unless root_group
+
+        can?(current_user, :apply_security_scan_profiles, project)
+      end
+
+      def can_read_attributes?
+        return false unless root_group
+
+        can?(current_user, :read_security_attribute, root_group)
+      end
+
+      def can_manage_attributes?
+        return false unless root_group
+
+        can?(current_user, :admin_security_attributes, root_group)
+      end
+
+      def root_group
+        @root_group ||= project.root_ancestor if project.root_ancestor.is_a?(Group)
+      end
+
       def gitlab_com?; end
+      def max_tracked_refs; end
       def validity_checks_available; end
       def validity_checks_enabled; end
       def container_scanning_for_registry_enabled; end
       def secret_push_protection_enabled; end
       def secret_detection_configuration_path; end
       def license_configuration_source; end
+      def group_manage_attributes_path; end
     end
   end
 end
