@@ -19,11 +19,13 @@ module RapidDiffs
     end
 
     override(:reload_stream_url)
-    def reload_stream_url(offset: nil, diff_view: nil)
+    def reload_stream_url(offset: nil, diff_view: nil, skip_old_path: nil, skip_new_path: nil)
       diffs_stream_project_compare_index_path(
         resource.project,
         **request_params,
         offset: offset,
+        skip_old_path: skip_old_path,
+        skip_new_path: skip_new_path,
         view: diff_view
       )
     end
