@@ -2,6 +2,8 @@
 
 module Webauthn
   class RegisterService < BaseService
+    include Authn::WebauthnErrors
+
     def initialize(user, params, challenge)
       @user = user
       @params = params
@@ -15,7 +17,7 @@ module Webauthn
         webauthn_credential = WebAuthn::Credential.from_create(Gitlab::Json.safe_parse(@params[:device_response]))
         webauthn_credential.verify(@challenge)
 
-        registration.update(
+        registration.update!(
           credential_xid: Base64.strict_encode64(webauthn_credential.raw_id),
           public_key: webauthn_credential.public_key,
           counter: webauthn_credential.sign_count,
@@ -24,13 +26,25 @@ module Webauthn
           passkey_eligible: passkey?(webauthn_credential),
           last_used_at: Time.current
         )
-      rescue JSON::ParserError
-        registration.errors.add(:base, _('Your WebAuthn device did not send a valid JSON response.'))
-      rescue WebAuthn::Error => e
-        registration.errors.add(:base, e.message)
-      end
 
-      registration
+        ServiceResponse.success(
+          message: _('Your WebAuthn device was registered!'),
+          payload: registration
+        )
+      rescue JSON::ParserError
+        ServiceResponse.error(
+          message: _('Your WebAuthn device did not send a valid JSON response.'),
+          payload: registration
+        )
+      rescue ActiveRecord::RecordInvalid => err
+        ServiceResponse.error(
+          message: err.message
+        )
+      rescue WebAuthn::Error => err
+        ServiceResponse.error(
+          message: webauthn_human_readable_errors(err.class.name)
+        )
+      end
     end
 
     private
