@@ -46,6 +46,7 @@ module ActiveContext
 
         create_missing_migration_records!(migration_files - migration_records)
         delete_orphaned_migration_records!(migration_records - migration_files)
+        reevaluate_skipped_migrations!
       end
 
       def execute_current_migration
@@ -56,27 +57,38 @@ module ActiveContext
           return true
         end
 
-        process_migration!(migration_record)
+        migration_class = find_migration_class(migration_record.version)
+        migration_instance = migration_class.new
+
+        if migration_instance.skip?
+          mark_migration_as_skipped(migration_record)
+          return true
+        end
+
+        process_migration!(migration_record, migration_instance)
 
         true
       end
 
-      def process_migration!(migration_record)
-        migration_class = find_migration_class(migration_record.version)
+      def mark_migration_as_skipped(migration_record)
+        return if migration_record.skipped?
 
-        migration_instance = migration_class.new
+        log "Skipping migration #{migration_record.version}"
+        migration_record.skipped!
+      end
 
+      def process_migration!(migration_record, migration_instance)
         log "Starting migration #{migration_record.version}"
 
-        migration_record.mark_as_started!
+        migration_record.mark_as_started! unless migration_record.in_progress?
         migration_instance.migrate!
 
-        if migration_instance.all_operations_completed?
+        if migration_instance.completed?
           log "Marking migration #{migration_record.version} as completed"
 
           migration_record.mark_as_completed!
         else
-          log "Migration #{migration_record.version} partially completed, re-enqueueing worker"
+          log "Migration #{migration_record.version} incomplete, re-enqueueing worker"
 
           re_enqueue_worker
         end
@@ -106,6 +118,18 @@ module ActiveContext
         log "Deleted orphaned migration records for #{versions.join(', ')}"
       end
 
+      def reevaluate_skipped_migrations!
+        migrations.skipped.each do |migration_record|
+          migration_class = find_migration_class(migration_record.version)
+          migration_instance = migration_class.new
+
+          unless migration_instance.skip?
+            log "Migration #{migration_record.version} no longer skipped, marking as pending"
+            migration_record.pending!
+          end
+        end
+      end
+
       def re_enqueue_worker
         self.class.perform_in(RE_ENQUEUE_DELAY)
       end
