@@ -6,15 +6,11 @@ module ActiveContext
       class QueryResult
         include ActiveContext::Databases::Concerns::QueryResult
 
-        def count
-          result['hits']['total']['value']
-        end
-
         def each
           return enum_for(:each) unless block_given?
 
           result['hits']['hits'].each do |hit|
-            yield hit['_source']
+            yield hit['_source'].merge('score' => hit['_score'])
           end
         end
       end
