@@ -26,7 +26,8 @@ module API
           requires :metadata, type: Hash, desc: 'The metadata for the release'
         end
         route_setting :authentication, job_token_allowed: true
-        route_setting :authorization, job_token_policies: :admin_releases
+        route_setting :authorization, job_token_policies: :admin_releases, permissions: :publish_catalog_version,
+          boundary_type: :project
         # Note: This endpoint should only be used by CLI tools and should be authenticated with a job token.
         # For this reason, we should not document the endpoint in the API docs.
         post ':id/catalog/publish' do
