@@ -5,13 +5,14 @@ module Banzai
     module IncidentManagement
       class TimelineEventPipeline < PlainMarkdownPipeline
         ALLOWLIST = Banzai::Filter::SanitizationFilter::LIMITED.deep_dup.merge(
-          elements: %w(p b i strong em pre code a img)
+          elements: %w[p b i strong em pre code a img]
         ).freeze
 
         def self.filters
           @filters ||= FilterArray[
             *super,
             Filter::SanitizationFilter,
+            Filter::SanitizeLinkFilter,
             *Banzai::Pipeline::GfmPipeline.reference_filters,
             Filter::EmojiFilter,
             Filter::ExternalLinkFilter,
