@@ -61,10 +61,12 @@ module Gitlab
           notes_create: { threshold: -> { application_settings.notes_create_limit }, interval: 1.minute },
           notification_emails: { threshold: 1000, interval: 1.day },
           oauth_dynamic_registration: { threshold: 5, interval: 1.hour },
+          offline_export: { threshold: 6, interval: 1.minute },
           permanent_email_failure: { threshold: 5, interval: 1.day },
           phone_verification_send_code: { threshold: 5, interval: 1.day },
           phone_verification_verify_code: { threshold: 5, interval: 1.day },
           pipelines_create: { threshold: -> { application_settings.pipeline_limit_per_project_user_sha }, interval: 1.minute },
+          pipelines_created_per_user: { threshold: -> { application_settings.pipeline_limit_per_user }, interval: 1.minute },
           play_pipeline_schedule: { threshold: 1, interval: 1.minute },
           profile_add_new_email: { threshold: 5, interval: 1.minute },
           profile_resend_email_confirmation: { threshold: 5, interval: 1.minute },
@@ -199,7 +201,7 @@ module Gitlab
         end
 
         throttled?(key, scope: scope, **options).tap do |throttled|
-          log_request(request, "#{key}_request_limit".to_sym, current_user) if throttled
+          log_request(request, :"#{key}_request_limit", current_user) if throttled
         end
       end
 
