@@ -22,6 +22,7 @@ module Gitlab
 
         def insert!
           return false if tag_list_by_taggable.empty?
+          return true unless config.uses_taggings?
 
           persist_build_tags!
         end
@@ -46,6 +47,7 @@ module Gitlab
         def persist_build_tags!
           all_tags = tag_list_by_taggable.values.flatten.uniq.reject(&:blank?)
           tag_records_by_name = create_tags(all_tags).index_by(&:name)
+
           taggings = build_taggings(tag_records_by_name)
 
           join_model.bulk_insert!(
@@ -60,9 +62,8 @@ module Gitlab
           true
         end
 
-        # rubocop: disable CodeReuse/ActiveRecord
         def create_tags(tags)
-          existing_tag_records = ::Ci::Tag.where(name: tags).to_a
+          existing_tag_records = ::Ci::Tag.named(tags).to_a
           missing_tags = detect_missing_tags(tags, existing_tag_records)
           return existing_tag_records if missing_tags.empty?
 
@@ -72,9 +73,8 @@ module Gitlab
               ::Ci::Tag.insert_all!(tags_attributes)
             end
 
-          ::Ci::Tag.where(name: tags).to_a
+          ::Ci::Tag.named(tags).to_a
         end
-        # rubocop: enable CodeReuse/ActiveRecord
 
         def build_taggings(tag_records_by_name)
           accumulator = []
