@@ -49,21 +49,12 @@ module Gitlab
           setup_class_attribute(:connection, ConnectionProxy.new(load_balancer))
           setup_class_attribute(:sticking, Sticking.new(load_balancer))
 
-          return unless ::Gitlab.next_rails?
-
           @model.singleton_class.alias_method(:lease_connection, :connection)
           @model.singleton_class.define_method(:with_connection) do |*_args, **_kwargs, &block|
-            next block&.call(connection) unless connection.is_a?(ConnectionProxy)
-
-            connection_already_checked_out = load_balancer.connection_checked_out?
-
-            begin
-              block&.call(connection)
-            ensure
-              # When connections are already checked out before the `with_connection` block,
-              # we leave them as-is as we expect those to be released by the code that checked them out.
-              load_balancer.release_connections unless connection_already_checked_out
-            end
+            # The original rails with_connection would return the connection to the pool,
+            # but here we don't know if it's a primary or replica connection yet, so we keep it checked out for
+            # the duration of the request
+            block&.call(connection)
           end
         end
 
