@@ -157,7 +157,7 @@ module Gitlab
           end
 
           def ordering_from_encoded_json(cursor)
-            Gitlab::Json.parse(decode(cursor))
+            Gitlab::Json.safe_parse(decode(cursor))
           rescue JSON::ParserError
             raise Gitlab::Graphql::Errors::ArgumentError, "Please provide a valid cursor"
           end
