@@ -21,7 +21,7 @@ module Gitlab
           return unless Gitlab::Runtime.puma?
 
           stats = ::Puma.stats
-          stats = Gitlab::Json.parse(stats)
+          stats = Gitlab::Json.safe_parse(stats)
 
           # If `workers` is missing this means that
           # Puma server is running in single mode
